@@ -1,10 +1,10 @@
 package Strehler::API;
-
+$Strehler::API::VERSION = '1.3.1';
+use strict;
 use Dancer2 0.153002;
 use Dancer2::Serializer::JSON;
 use Strehler::Helpers;
 use Strehler::Meta::Category;
-use Data::Dumper;
 
 prefix '/api/v1';
 
