@@ -1,7 +1,6 @@
 package Strehler::Dancer2::Plugin;
-{
-    $Strehler::Dancer2::Plugin::VERSION = '1.0.0';
-}
+$Strehler::Dancer2::Plugin::VERSION = '1.3.1';
+use strict;
 use Dancer2::Plugin;
 use Strehler::Helpers;
 
