@@ -1,5 +1,6 @@
 package Strehler::Meta::Tag;
-
+$Strehler::Meta::Tag::VERSION = '1.3.1';
+use strict;
 use Moo;
 use Dancer2 0.153002;
 use Dancer2::Plugin::DBIC;
